summaryrefslogtreecommitdiff
path: root/tests/auto/nokia_services
diff options
context:
space:
mode:
authorAlex Blasche <alexander.blasche@theqtcompany.com>2015-03-04 16:40:14 +0100
committerAlex Blasche <alexander.blasche@theqtcompany.com>2015-03-25 07:51:46 +0000
commit3216d71dae42126c3d730ce56b616abebd1c5b87 (patch)
treefacd0662a0fd25f1b9586fccbc21ac7cdf9547d7 /tests/auto/nokia_services
parentf738357f041291eb42c8f6a6d5ca9aa1dd4ebfb1 (diff)
downloadqtlocation-3216d71dae42126c3d730ce56b616abebd1c5b87.tar.gz
Changes key of "nokia" geoservices plugin to "here"
The old name is not advertised anymore but the plugin can still be loaded using the "nokia" key. This will be removed by later versions of Qt. Adds a QGeoServiceProvider unit tests Change-Id: I01f36f1bb19d31e0855e90c1605b99e61ee4450b Reviewed-by: Michal Klocek <michal.klocek@theqtcompany.com> Reviewed-by: Alex Blasche <alexander.blasche@theqtcompany.com> Reviewed-by: Aaron McCarthy <mccarthy.aaron@gmail.com>
Diffstat (limited to 'tests/auto/nokia_services')
-rw-r--r--tests/auto/nokia_services/places_semiauto/tst_places.cpp10
-rw-r--r--tests/auto/nokia_services/routing/tst_routing.cpp4
2 files changed, 7 insertions, 7 deletions
diff --git a/tests/auto/nokia_services/routing/tst_routing.cpp b/tests/auto/nokia_services/routing/tst_routing.cpp
index a664a8dd..53deb55d 100644
--- a/tests/auto/nokia_services/routing/tst_routing.cpp
+++ b/tests/auto/nokia_services/routing/tst_routing.cpp
@@ -323,7 +323,7 @@ void tst_nokia_routing::routingError(QGeoRouteReply* reply, QGeoRouteReply::Erro
void tst_nokia_routing::initTestCase()
{
QStringList providers = QGeoServiceProvider::availableServiceProviders();
- QVERIFY(providers.contains(QStringLiteral("nokia")));
+ QVERIFY(providers.contains(QStringLiteral("here")));
m_networkManager = new MockGeoNetworkAccessManager();
@@ -332,7 +332,7 @@ void tst_nokia_routing::initTestCase()
parameters.insert(QStringLiteral("app_id"), "stub");
parameters.insert(QStringLiteral("token"), "stub");
- m_geoServiceProvider = new QGeoServiceProvider(QStringLiteral("nokia"), parameters);
+ m_geoServiceProvider = new QGeoServiceProvider(QStringLiteral("here"), parameters);
QVERIFY(m_geoServiceProvider);
m_routingManager = m_geoServiceProvider->routingManager();
diff --git a/tests/auto/nokia_services/places_semiauto/tst_places.cpp b/tests/auto/nokia_services/places_semiauto/tst_places.cpp
index 2e80036a..be939e35 100644
--- a/tests/auto/nokia_services/places_semiauto/tst_places.cpp
+++ b/tests/auto/nokia_services/places_semiauto/tst_places.cpp
@@ -109,12 +109,12 @@ void tst_QPlaceManagerNokia::initTestCase()
{
QVariantMap params;
QStringList providers = QGeoServiceProvider::availableServiceProviders();
- QVERIFY(providers.contains("nokia"));
+ QVERIFY(providers.contains("here"));
#ifndef QT_NO_PROCESS
QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
if (!(env.contains(AppIdEnv) && env.contains(TokenEnv)))
- QSKIP("NOKIA_APP_ID and NOKIA_TOKEN environment variables not set");\
+ QSKIP("NOKIA_APPID and NOKIA_TOKEN environment variables not set");\
params.insert(QStringLiteral("app_id"), env.value(AppIdEnv));
params.insert(QStringLiteral("token"), env.value(TokenEnv));
@@ -122,9 +122,9 @@ void tst_QPlaceManagerNokia::initTestCase()
if (env.contains(ProxyEnv))
params.insert(QStringLiteral("proxy"), env.value(ProxyEnv));
#else
- QSKIP("Cannot parse process environment, NOKIA_APP_ID and NOKIA_TOKEN not set");
+ QSKIP("Cannot parse process environment, NOKIA_APPID and NOKIA_TOKEN not set");
#endif
- provider = new QGeoServiceProvider("nokia", params);
+ provider = new QGeoServiceProvider("here", params);
placeManager = provider->placeManager();
QVERIFY(placeManager);
}
@@ -436,7 +436,7 @@ void tst_QPlaceManagerNokia::categories()
//check we can retrieve the very same category by id
QCOMPARE(placeManager->category(category.categoryId()), category);
//since the nokia plugin only supports a single level category tree
//check that there are no parent or children categories
QVERIFY(placeManager->parentCategoryId(category.categoryId()).isEmpty());
QVERIFY(placeManager->childCategories(category.categoryId()).isEmpty());
@@ -436,7 +436,7 @@ void tst_QPlaceManagerNokia::categories()
//check we can retrieve the very same category by id
QCOMPARE(placeManager->category(category.categoryId()), category);
- //since the nokia plugin only supports a single level category tree
+ //since the here plugin only supports a single level category tree
//check that there are no parent or children categories
QVERIFY(placeManager->parentCategoryId(category.categoryId()).isEmpty());